@@ -1,14 +1,14 @@
 package Data::Sah::Coerce::perl::To_str::From_str::to_ean8;
 
-# AUTHOR
-our $DATE = '2020-03-08'; # DATE
-our $DIST = 'Sah-Schemas-EAN'; # DIST
-our $VERSION = '0.007'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-01-27'; # DATE
+our $DIST = 'Sah-Schemas-EAN'; # DIST
+our $VERSION = '0.008'; # VERSION
+
 sub meta {
     +{
         v => 4,
@@ -58,7 +58,7 @@ Data::Sah::Coerce::perl::To_str::From_str::to_ean8 - Check and format EAN-8 numb
 
 =head1 VERSION
 
-This document describes version 0.007 of Data::Sah::Coerce::perl::To_str::From_str::to_ean8 (from Perl distribution Sah-Schemas-EAN), released on 2020-03-08.
+This document describes version 0.008 of Data::Sah::Coerce::perl::To_str::From_str::to_ean8 (from Perl distribution Sah-Schemas-EAN), released on 2023-01-27.
 
 =head1 SYNOPSIS
 
@@ -76,6 +76,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-EAN>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2020, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-EAN>
@@ -84,15 +113,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
